<?php
session_start();

/*
Plugin Name: sts-dropdown-css
Plugin URI: http://www.acheta.de/sts-dropdown/
Description: This plugin creates a drop down menu for static pages, links, categories and the archiven with css, not javascript.
Author: Stefan Schwenk
Version: 2.00
Author URI: http://www.acheta.de/
*/



function &sts_get_page_children($page_id, $pages) {
	global $page_cache;

	if ( empty($pages) )
		$pages = &$page_cache;

	$page_list = array();
	foreach ( $pages as $page ) {
		if ( $page->post_parent == $page_id ) {
			$page_list[] = $page;
			if ( $children = sts_get_page_children($page->ID, $pages) )
				$page_list = array_merge($page_list, $children);
		}
	}
	return $page_list;
}


function &sts_get_pages($args = '') {
	global $wpdb;

	parse_str($args, $r);

	if ( !isset($r['child_of']) )
		$r['child_of'] = 0;
	if ( !isset($r['sort_column']) )
		$r['sort_column'] = 'post_title';
	if ( !isset($r['sort_order']) )
		$r['sort_order'] = 'ASC';

	$exclusions = '';
	if ( !empty($r['exclude']) ) {
		$expages = preg_split('/[\s,]+/',$r['exclude']);
		if ( count($expages) ) {
			foreach ( $expages as $expage ) {
				$exclusions .= ' AND ID <> ' . intval($expage) . ' ';
			}
		}
	}

	$pages = $wpdb->get_results("SELECT * " .
		"FROM $wpdb->posts " .
		"WHERE post_type = 'page' AND post_status = 'publish' " .
		"$exclusions " .
		"ORDER BY " . $r['sort_column'] . " " . $r['sort_order']);

	if ( empty($pages) )
		return array();

	// Update cache.
	update_page_cache($pages);

	if ( $r['child_of'] )
		$pages = & sts_get_page_children($r['child_of'], $pages);

	return $pages;
}


function sts_list_pages($args = '') {
	parse_str($args, $r);
	if ( !isset($r['depth']) )
		$r['depth'] = 0;
	if ( !isset($r['show_date']) )
		$r['show_date'] = '';
	if ( !isset($r['child_of']) )
		$r['child_of'] = 0;
	if ( !isset($r['title_li']) )
		$r['title_li'] = __('Pages');
	if ( !isset($r['echo']) )
		$r['echo'] = 1;

	$output = '';

	// Query pages.
	$pages = & sts_get_pages($args);
	if ( $pages ) {


			$output .= "\n<div class=\"barrow\">\n<ul class=\"drop\">\n";

		// Now loop over all pages that were selected
		$page_tree = Array();
		foreach ( $pages as $page ) {
			// set the title for the current page
			$page_tree[$page->ID]['title'] = $page->post_title;
			$page_tree[$page->ID]['name'] = $page->post_name;

			// set the selected date for the current page
			// depending on the query arguments this is either
			// the createtion date or the modification date
			// as a unix timestamp. It will also always be in the
			// ts field.
			if ( !empty($r['show_date']) ) {
				if ( 'modified' == $r['show_date'] )
					$page_tree[$page->ID]['ts'] = $page->post_modified;
				else
					$page_tree[$page->ID]['ts'] = $page->post_date;
			}

			// The tricky bit!!
			// Using the parent ID of the current page as the
			// array index we set the curent page as a child of that page.
			// We can now start looping over the $page_tree array
			// with any ID which will output the page links from that ID downwards.
			if ( $page->post_parent != $page->ID)
				$page_tree[$page->post_parent]['children'][] = $page->ID;
		}
		// Output of the pages starting with child_of as the root ID.
		// child_of defaults to 0 if not supplied in the query.
		$output .= sts_page_level_out($r['child_of'],$page_tree, $r, 0, false);

			$output .= "</ul>\n</div>\n";
	}

	$output = apply_filters('sts_list_pages', $output);

	if ( $r['echo'] )
		echo $output;
	else
		return $output;
}


function sts_page_level_out($parent, $page_tree, $args, $depth = 0, $echo = true) {
	global $wp_query;
	$queried_obj = $wp_query->get_queried_object();
	$output = '';

	if ( $depth )
		$indent = str_repeat("\t", $depth);
		//$indent = join('', array_fill(0,$depth,"\t"));

	if ( !is_array($page_tree[$parent]['children']) )
		return false;

	foreach ( $page_tree[$parent]['children'] as $page_id ) {
		$cur_page = $page_tree[$page_id];
		$title = $cur_page['title'];

		$css_class = 'page_item';
		if ( $page_id == $queried_obj->ID )
			$css_class .= ' current_page_item';


		if ( $page = $parent && $page = $cur_page['children'] )
			$output .= $indent . '<li onmouseover="this.className=\'msieFix\'" onmouseout="this.className=\'\'"><a href="' . get_page_link($page_id) . '" title="' . wp_specialchars($title) . '">' . $title . ' &#187;</a>';
		else
			$output .= $indent . '<li onmouseover="this.className=\'msieFix\'" onmouseout="this.className=\'\'"><a href="' . get_page_link($page_id) . '" title="' . wp_specialchars($title) . '">' . $title . '</a>';


		if ( isset($cur_page['ts']) ) {
			$format = get_settings('date_format');
			if ( isset($args['date_format']) )
				$format = $args['date_format'];
			$output .= " " . mysql2date($format, $cur_page['ts']);
		}

		if ( isset($cur_page['children']) && is_array($cur_page['children']) ) {
			$new_depth = $depth + 1;

			if ( !$args['depth'] || $depth < ($args['depth']-1) ) {
				if ( $page = $parent )
					$output .= "\n $indent <ul>\n $indent $indent<li onmouseover=\"this.className='msieFix'\" onmouseout=\"this.className=''\"><a class=\"backarrow\"> &#187;</a></li>\n";
				else
					$output .= "\n $indent <ul>\n";
				$output .= sts_page_level_out($page_id, $page_tree, $args, $new_depth, false);
				$output .= " $indent </ul>\n";
			}
		}
		$output .= "$indent</li>\n";
	}
	if ( $echo )
		echo $output;
	else
		return $output;
}


function sts_links_list($order = 'name', $hide_if_empty = 'obsolete') {
	$order = strtolower($order);

	// Handle link category sorting
	$direction = 'ASC';
	if ( '_' == substr($order,0,1) ) {
		$direction = 'DESC';
		$order = substr($order,1);
	}

	if ( !isset($direction) )
		$direction = '';

	$cats = get_categories("type=link&orderby=$order&order=$direction&hierarchical=0");

	// Display each category
	if ( $cats ) {
		foreach ( (array) $cats as $cat ) {
			// Handle each category.

			// Display the category name
			echo "\n<div class=\"barrow\">\n <ul class=\"drop\">\n\t<li onmouseover=\"this.className='msieFix'\" onmouseout=\"this.className=''\"><a>" . $cat->cat_name . "</a>\n\t    <ul>\n";
			// Call get_links() with all the appropriate params
			get_links($cat->cat_ID, '		<li onmouseover="this.className=\'msieFix\'" onmouseout="this.className=\'\'">', "</li>", "\n", true, 'name', false);

			// Close the last category
			echo "\n\t   </ul>\n\t</li>\n </ul>\n</div>\n";
		}
	}
}


function sts_list_cats($args = '') {
	parse_str($args, $r);
	if ( !isset($r['optionall']))
		$r['optionall'] = 0;
	if ( !isset($r['all']))
		$r['all'] = 'All';
	if ( !isset($r['sort_column']) )
		$r['sort_column'] = 'ID';
	if ( !isset($r['sort_order']) )
		$r['sort_order'] = 'asc';
	if ( !isset($r['file']) )
		$r['file'] = '';
	if ( !isset($r['list']) )
		$r['list'] = true;
	if ( !isset($r['optiondates']) )
		$r['optiondates'] = 0;
	if ( !isset($r['optioncount']) )
		$r['optioncount'] = 0;
	if ( !isset($r['hide_empty']) )
		$r['hide_empty'] = 1;
	if ( !isset($r['use_desc_for_title']) )
		$r['use_desc_for_title'] = 1;
	if ( !isset($r['children']) )
		$r['children'] = true;
	if ( !isset($r['child_of']) )
		$r['child_of'] = 0;
	if ( !isset($r['categories']) )
		$r['categories'] = 0;
	if ( !isset($r['recurse']) )
		$r['recurse'] = 0;
	if ( !isset($r['feed']) )
		$r['feed'] = '';
	if ( !isset($r['feed_image']) )
		$r['feed_image'] = '';
	if ( !isset($r['exclude']) )
		$r['exclude'] = '';
	if ( !isset($r['hierarchical']) )
		$r['hierarchical'] = true;

	$vor = "\n<div class=\"barrow\">\n <ul class=\"drop\">\n\t<li onmouseover=\"this.className='msieFix'\" onmouseout=\"this.className=''\"><a>categories</a>\n\t <ul>\n";

	$nach = "\n\t </ul>\n\t</li>\n </ul>\n</div>";

	echo $vor;

	$mitte = stsdrop_list_cats($r['optionall'], $r['all'], $r['sort_column'], $r['sort_order'], $r['file'],	$r['list'], $r['optiondates'], $r['optioncount'], $r['hide_empty'], $r['use_desc_for_title'], $r['children'], $r['child_of'], $r['categories'], $r['recurse'], $r['feed'], $r['feed_image'], $r['exclude'], $r['hierarchical']);

	echo $mitte;
	
	echo $nach;
}

function stsdrop_list_cats($optionall = 1, $all = 'All', $sort_column = 'ID', $sort_order = 'asc', $file = '', $list = true, $optiondates = 0, $optioncount = 0, $hide_empty = 1, $use_desc_for_title = 1, $children=FALSE, $child_of=0, $categories=0, $recurse=0, $feed = '', $feed_image = '', $exclude = '', $hierarchical=FALSE) {
	global $wpdb, $wp_query;
	// Optiondates now works
	if ( '' == $file )
		$file = get_settings('home') . '/';

	$exclusions = '';
	if ( !empty($exclude) ) {
		$excats = preg_split('/[\s,]+/',$exclude);
		if ( count($excats) ) {
			foreach ( $excats as $excat ) {
				$exclusions .= ' AND cat_ID <> ' . intval($excat) . ' ';
			}
		}
	}

	$exclusions = apply_filters('list_cats_exclusions', $exclusions );

	if ( intval($categories) == 0 ) {
		$sort_column = 'cat_'.$sort_column;

		$query = "
			SELECT cat_ID, cat_name, category_nicename, category_description, category_parent, category_count
			FROM $wpdb->categories
			WHERE cat_ID > 0 $exclusions
			ORDER BY $sort_column $sort_order";

		$categories = $wpdb->get_results($query);
	}

	if ( $optiondates ) {
		$cat_dates = $wpdb->get_results("	SELECT category_id,
		UNIX_TIMESTAMP( MAX(post_date) ) AS ts
		FROM $wpdb->posts, $wpdb->post2cat, $wpdb->categories
		WHERE post_status = 'publish' AND post_id = ID $exclusions
		GROUP BY category_id");
		foreach ( $cat_dates as $cat_date ) {
			$category_timestamp["$cat_date->category_id"] = $cat_date->ts;
		}
	}

	$num_found=0;
	$thelist = "";

	foreach ( $categories as $category ) {
		if ( ( intval($hide_empty) == 0 || $category->category_count) && (!$hierarchical || $category->category_parent == $child_of) ) {
			$num_found++;
			$link = '<a href="'.get_category_link($category->cat_ID).'" ';
			if ( $use_desc_for_title == 0 || empty($category->category_description) )
				$link .= 'title="'. sprintf(__("View all posts filed under %s"), wp_specialchars($category->cat_name)) . '"';
			else
				$link .= 'title="' . wp_specialchars(apply_filters('category_description',$category->category_description,$category)) . '"';
			$link .= '>';
			$link .= apply_filters('list_cats', $category->cat_name, $category);

			if ( (! empty($feed_image)) || (! empty($feed)) ) {

				$link .= ' ';

				if ( empty($feed_image) )
					$link .= '(';

				$link .= '<a href="' . get_category_rss_link(0, $category->cat_ID, $category->category_nicename) . '"';

				if ( !empty($feed) ) {
					$title = ' title="' . $feed . '"';
					$alt = ' alt="' . $feed . '"';
					$name = $feed;
					$link .= $title;
				}

				$link .= '>';

				if ( !empty($feed_image) )
					$link .= "<img src='$feed_image' $alt$title" . ' />';
				else
					$link .= $name;

				$link .= '</a>';

				if (empty($feed_image))
					$link .= ')';
			}

			if ( intval($optioncount) == 1 )
				$link .= ' ('.intval($category->category_count).')';

			if ( $optiondates ) {
				if ( $optiondates == 1 )
					$optiondates = 'Y-m-d';
				$link .= ' ' . gmdate($optiondates, $category_timestamp["$category->cat_ID"]);
			}
				$link .= '</a>';
			if ( $list ) {
				$thelist .= "\t\t<li onmouseover=\"this.className='msieFix'\" onmouseout=\"this.className=''\"";
				if (($category->cat_ID == $wp_query->get_queried_object_id()) && is_category()) {
					$thelist .=  ' class="current-cat"';
				}
				$thelist .= ">$link";
			} else {
				$thelist .= "\t$link<br />\n";
			}

			if ($hierarchical && $children)
				$thelist .= stsdrop_list_cats($optionall, $all, $sort_column, $sort_order, $file, $list, $optiondates, $optioncount, $hide_empty, $use_desc_for_title, $hierarchical, $category->cat_ID, $categories, 1, $feed, $feed_image, $exclude, $hierarchical);
			if ($list)
				$thelist .= "\t\t</li>\n";
		}
	}
	if ( !$num_found && !$child_of ) {
		if ( $list ) {
			$before = '<li>';
			$after = '</li>';
		}
		echo $before . __("No categories") . $after . "\n";
		return;
	}
	if ( $list && $child_of && $num_found && $recurse ) {
		$pre = "\n\t\t\t<ul>\n\t\t ";
		$post = "\t\t\t</ul>\n";
	} else {
		$pre = $post = '';
	}
	$thelist = $pre . $thelist . $post;
	if ( $recurse )
		return $thelist;
	echo apply_filters('stsdrop_list_cats', $thelist);
}

function sts_in_category($category) { // Check if the current post is in the given category
	global $category_cache, $post;

	if ( isset( $category_cache[$post->ID][$category] ) )
		return true;
	else
		return false;
}


/* link navigation hack by Orien http://icecode.com/ */
function sts_get_archives_link($url, $text, $format = 'html', $before = '', $after = '') {
	$text = wptexturize($text);
	$title_text = wp_specialchars($text, 1);

	if ('link' == $format)
		return "\t<link rel='archives' title='$title_text' href='$url' />\n";
	elseif ('option' == $format)
		return "\t<option value='$url'>$before $text $after</option>\n";
	elseif ('html' == $format)
		return "\t\t<li onmouseover=\"this.className='msieFix'\" onmouseout=\"this.className=''\">$before<a href='$url' title='$title_text'>$text</a>$after</li>\n";
	else // custom
		return "\t$before<a href='$url' title='$title_text'>$text</a>$after\n";
}


function sts_get_archives($args = '') {
	parse_str($args, $r);
	if ( !isset($r['type']) )
		$r['type'] = '';
	if ( !isset($r['limit']) )
		$r['limit'] = '';
	if ( !isset($r['format']) )
		$r['format'] = 'html';
	if ( !isset($r['before']) )
		$r['before'] = '';
	if ( !isset($r['after']) )
		$r['after'] = '';
	if ( !isset($r['show_post_count']) )
		$r['show_post_count'] = false;

	$vor = "\n<div class=\"barrow\">\n <ul class=\"drop\">\n\t<li onmouseover=\"this.className='msieFix'\" onmouseout=\"this.className=''\"><a>archive</a>\n\t <ul>\n";
	
	$nach = "\n\t </ul>\n\t</li>\n </ul>\n</div>\n";

	echo $vor;

	$mitte = sts_archivget_archives($r['type'], $r['limit'], $r['format'], $r['before'], $r['after'], $r['show_post_count']);

	echo $mitte;

	echo $nach;
}


function sts_archivget_archives($type='', $limit='', $format='html', $before = '', $after = '', $show_post_count = false) {
	global $month, $wpdb;

	if ( '' == $type )
		$type = 'monthly';

	if ( '' != $limit ) {
		$limit = (int) $limit;
		$limit = ' LIMIT '.$limit;
	}
	// this is what will separate dates on weekly archive links
	$archive_week_separator = '&#8211;';

	// over-ride general date format ? 0 = no: use the date format set in Options, 1 = yes: over-ride
	$archive_date_format_over_ride = 0;

	// options for daily archive (only if you over-ride the general date format)
	$archive_day_date_format = 'Y/m/d';

	// options for weekly archive (only if you over-ride the general date format)
	$archive_week_start_date_format = 'Y/m/d';
	$archive_week_end_date_format	= 'Y/m/d';

	if ( !$archive_date_format_over_ride ) {
		$archive_day_date_format = get_settings('date_format');
		$archive_week_start_date_format = get_settings('date_format');
		$archive_week_end_date_format = get_settings('date_format');
	}

	$add_hours = intval(get_settings('gmt_offset'));
	$add_minutes = intval(60 * (get_settings('gmt_offset') - $add_hours));

	$now = current_time('mysql');

	if ( 'monthly' == $type ) {
		$arcresults = $wpdb->get_results("SELECT DISTINCT YEAR(post_date) AS `year`, MONTH(post_date) AS `month`, count(ID) as posts FROM $wpdb->posts WHERE post_date < '$now' AND post_date != '0000-00-00 00:00:00' AND post_status = 'publish' GROUP BY YEAR(post_date), MONTH(post_date) ORDER BY post_date DESC" . $limit);
		if ( $arcresults ) {
			$afterafter = $after;
			foreach ( $arcresults as $arcresult ) {
				$url	= get_month_link($arcresult->year,	$arcresult->month);
				if ( $show_post_count ) {
					$text = sprintf('%s %d', $month[zeroise($arcresult->month,2)], $arcresult->year);
					$after = '&nbsp;('.$arcresult->posts.')' . $afterafter;
				} else {
					$text = sprintf('%s %d', $month[zeroise($arcresult->month,2)], $arcresult->year);
				}
				echo sts_get_archives_link($url, $text, $format, $before, $after);
			}
		}
	} elseif ( 'daily' == $type ) {
		$arcresults = $wpdb->get_results("SELECT DISTINCT YEAR(post_date) AS `year`, MONTH(post_date) AS `month`, DAYOFMONTH(post_date) AS `dayofmonth` FROM $wpdb->posts WHERE post_date < '$now' AND post_date != '0000-00-00 00:00:00' AND post_status = 'publish' ORDER BY post_date DESC" . $limit);
		if ( $arcresults ) {
			foreach ( $arcresults as $arcresult ) {
				$url	= get_day_link($arcresult->year, $arcresult->month, $arcresult->dayofmonth);
				$date = sprintf("%d-%02d-%02d 00:00:00", $arcresult->year, $arcresult->month, $arcresult->dayofmonth);
				$text = mysql2date($archive_day_date_format, $date);
				echo sts_get_archives_link($url, $text, $format, $before, $after);
			}
		}
	} elseif ( 'weekly' == $type ) {
		$start_of_week = get_settings('start_of_week');
		$arcresults = $wpdb->get_results("SELECT DISTINCT WEEK(post_date, $start_of_week) AS `week`, YEAR(post_date) AS yr, DATE_FORMAT(post_date, '%Y-%m-%d') AS yyyymmdd FROM $wpdb->posts WHERE post_date < '$now' AND post_status = 'publish' ORDER BY post_date DESC" . $limit);
		$arc_w_last = '';
		if ( $arcresults ) {
				foreach ( $arcresults as $arcresult ) {
					if ( $arcresult->week != $arc_w_last ) {
						$arc_year = $arcresult->yr;
						$arc_w_last = $arcresult->week;
						$arc_week = get_weekstartend($arcresult->yyyymmdd, get_settings('start_of_week'));
						$arc_week_start = date_i18n($archive_week_start_date_format, $arc_week['start']);
						$arc_week_end = date_i18n($archive_week_end_date_format, $arc_week['end']);
						$url  = sprintf('%s/%s%sm%s%s%sw%s%d', get_settings('home'), '', '?', '=', $arc_year, '&amp;', '=', $arcresult->week);
						$text = $arc_week_start . $archive_week_separator . $arc_week_end;
						echo sts_get_archives_link($url, $text, $format, $before, $after);
					}
				}
		}
	} elseif ( 'postbypost' == $type ) {
		$arcresults = $wpdb->get_results("SELECT * FROM $wpdb->posts WHERE post_date < '$now' AND post_status = 'publish' ORDER BY post_date DESC" . $limit);
		if ( $arcresults ) {
			foreach ( $arcresults as $arcresult ) {
				if ( $arcresult->post_date != '0000-00-00 00:00:00' ) {
					$url  = get_permalink($arcresult);
					$arc_title = $arcresult->post_title;
					if ( $arc_title )
						$text = strip_tags($arc_title);
					else
						$text = $arcresult->ID;
					echo sts_get_archives_link($url, $text, $format, $before, $after);
				}
			}
		}
	}
}



function sts_drop_css()
	{
?>
<style type="text/css" media="screen">

.drop,.drop ul {
	padding:0;margin:0 0px;
z-index: 195;
}

.drop {
	margin: 0 0 0 30px;
z-index: 195;
}

.drop li ul a {
	padding-left:1.5em;
	margin: 0px 0 0 0;
	z-index:99;
}

.drop li {
	float:left;
	width:116px;
	position:relative;
	list-style-type:none;
	font-weight:600;
	line-height: 18px;
	z-index:99;
}

.drop li a {
	margin-left: 0px;
	padding-left: 1em;
	display: block;
	color: #333;
	background-color: #eee;
	text-decoration: none;
	border: 1px solid #333;

}

.drop li a:hover {
	color: #333;
	background-color: #eee;

}

.drop li ul a {
	width: 99px;
	color: #fff;
	background-color: #ccc;
	line-height: 14px;
	font-weight:normal;

}

.drop li ul a:hover {
	margin-left: 0px;
	width: 99px;
	background-color: #eee;
	color: #333;
	font-weight:bold;

}

.drop li li ul a {
	width:99px;
	color: #333;
	background-color: #ddd;
	line-height: 14px;
	font-weight:normal;

}

.drop li ul li {
	background-color: transparent;
	width: 115px;
	margin-left: 0px;

}

.drop li ul li ul {
	visibility:hidden;
	position: absolute;
	top: 0px;
	background-color: transparent;
	width: 115px;
	margin-left: 116px;

}


.drop li ul {
	visibility:hidden;
	position:absolute;
	width:99px;

}

.drop ul ul li {
	visibility:hidden;
	position:absolute;
	width:109px;

}


.drop li:hover ul,.drop li.msieFix ul {
	visibility:visible;
	background-color:transparent;

}

.drop li li:hover li,.drop li li.msieFix li{
	visibility:visible;
	position:relative;
	background-color:transparent;

}

* html .drop li:hover ul,* html .drop li.msieFix ul {
	top:2em;
	left:0em;

}

* html .drop li li:hover li,* html .drop li li.msieFix li {
	top:-2em;
	left:0em;

}

.barrow {
	margin: 0px;
	background-color: transparent;
	z-index:99;
}

h1 a {
	clear:left;
}

.drop li ul li a.backarrow {
	background-color: #eee;
	font-weight: bold;
	color: #333;
}




</style>

<?php

	}
add_filter('wp_head', 'sts_drop_css');
?>